@@ -1,3 +1,6 @@
+import logging
+import sys
+
 import scrapy
 
 
@@ -10,6 +13,7 @@ class SettingsSpider(scrapy.Spider):
     def __init__(
             self,
             url,
+            path,
             pipe,
 
     ):
@@ -17,6 +21,7 @@ class SettingsSpider(scrapy.Spider):
 
         self.start_urls = url
         self.pipe = pipe
+        self.save = path
 
     def start_requests(self):
         yield scrapy.Request(self.start_urls)
@@ -42,7 +47,9 @@ class SettingsSpider(scrapy.Spider):
     def yield_raw_settings(self, response):
         raw = response.urljoin(response.xpath("//div[@class='BtnGroup']/a/@href").get())
 
-        self.pipe(raw)
+        self.pipe(
+            self.save, raw
+        )
 
         yield {
             "raw_link": raw
