@@ -1,8 +1,10 @@
 from .Settings import SettingsSpider
 from .Repo import RepoSpider, TempHandler
+from .ModuleChecker import ModuleCheckerSpider
 
 __all__ = [
     "SettingsSpider",
     "RepoSpider",
-    "TempHandler"
+    "TempHandler",
+    "ModuleCheckerSpider"
 ]
