@@ -1,4 +1,3 @@
-import multiprocessing
 import os
 import json
 import threading
@@ -283,14 +282,66 @@ class Processes:
             while True:
                 pass
 
-    @staticmethod
-    def search(url, queue: multiprocessing.Queue):
-        def results(path, raw):
-            queue.put(raw)
+    @classmethod
+    def search(
+            cls,
+            url,
+            result
+    ):
+        collect = []
 
-        process = scrapy.crawler.CrawlerProcess()
-        process.crawl(SettingsSpider, url=url, pipe=results, path=None)
-        process.start()
+        file = JsonHandler(os.path.join(
+            os.path.dirname(__file__), "settings.json"
+        ))
+
+        def error_pipe(failure):
+            result.put(
+                False
+            )
+
+            result.put(
+                repr(
+                    failure
+                )
+            )
+
+        def result_pipe(entity):
+            collect.append(entity)
+
+        parsed = file.load()
+
+        if url in parsed["general"]["modules"].values() or url in parsed["user"]["modules"].values():
+            return error_pipe(
+                "Already Exists"
+            )
+
+        try:
+            process = scrapy.crawler.CrawlerProcess()
+            process.crawl(
+                ModuleCheckerSpider, url=url, pipe=result_pipe, err_back=error_pipe
+            )
+            process.start()
+
+        except Exception as error:
+            return error_pipe(
+                error
+            )
+
+        if collect[-1]:
+
+            result.put(
+                True
+            )
+
+            for _ in collect[: -1]:
+                result.put(
+                    _
+                )
+
+        else:
+            error_pipe(
+                "Wrong format for module!"
+            )
 
 
 gc.collect()
